summaryrefslogtreecommitdiffstats
path: root/libraries/libreadline-java/patches/8f1e8f8357c48088f72952860ede68f54dc61d8e.patch
blob: a7ff0efdb0ceb80cab0ca62b80469d539c510784 (plain)
From 8f1e8f8357c48088f72952860ede68f54dc61d8e Mon Sep 17 00:00:00 2001
From: Andrew Clemons <andrew.clemons@gmail.com>
Date: Sat, 10 Jun 2017 19:28:41 +1200
Subject: [PATCH] Fix collision with getline(3).

---
 src/native/getline.c | 16 ++++++++--------
 src/native/getline.h |  6 +++---
 2 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/src/native/getline.h b/src/native/getline.h
index a10bb47..e8dc8b2 100644
--- a/src/native/getline.h
+++ b/src/native/getline.h
@@ -9,7 +9,7 @@
 
 extern char* rl_readline_name;                  /* unused by getline   */
 #define add_history(buffer) gl_histadd(buffer)
-#define readline(buffer)    getline(buffer)
+#define readline(buffer)    get_line(buffer)
 #define clear_history()     hist_init()
 #define using_history()     hist_init()
 
@@ -18,7 +18,7 @@ extern char* rl_readline_name;                  /* unused by getline   */
 
 typedef size_t (*gl_strwidth_proc)(char *);
 
-char           *getline(char *);		/* read a line of input */
+char           *get_line(char *);		/* read a line of input */
 void            gl_setwidth(int);		/* specify width of screen */
 void            gl_histadd(char *);		/* adds entries to hist */
 void		gl_strwidth(gl_strwidth_proc);	/* to bind gl_strlen */
@@ -30,7 +30,7 @@ extern int	(*gl_tab_hook)(char *, int, int *);
 
 #else	/* not __STDC__ */
 
-char           *getline();	
+char           *get_line();	
 void            gl_setwidth();
 void            gl_histadd();
 void		gl_strwidth();
diff --git a/src/native/getline.c b/src/native/getline.c
index f9b3304..58e26e3 100644
--- a/src/native/getline.c
+++ b/src/native/getline.c
@@ -41,7 +41,7 @@ char* rl_readline_name;
 
 /********************* exported interface ********************************/
 
-char           *getline();		/* read a line of input */
+char           *get_line();		/* read a line of input */
 void            gl_setwidth();		/* specify width of screen */
 void            gl_histadd();		/* adds entries to hist */
 void		gl_strwidth();		/* to bind gl_strlen */
@@ -387,7 +387,7 @@ gl_init()
         hist_init();
     }
     if (isatty(0) == 0 || isatty(1) == 0)
-	gl_error("\n*** Error: getline(): not interactive, use stdio.\n");
+	gl_error("\n*** Error: get_line(): not interactive, use stdio.\n");
     gl_char_init();
     gl_init_done = 1;
 }
@@ -414,7 +414,7 @@ int  w;
 }
 
 char *
-getline(prompt)
+get_line(prompt)
 char *prompt;
 {
     int             c, loc, tmp;
@@ -585,7 +585,7 @@ int c;
     int  i;
 
     if (gl_cnt >= BUF_SIZE - 1)
-	gl_error("\n*** Error: getline(): input buffer overflow\n");
+	gl_error("\n*** Error: get_line(): input buffer overflow\n");
     if (gl_overwrite == 0 || gl_pos == gl_cnt) {
         for (i=gl_cnt; i >= gl_pos; i--)
             gl_buf[i+1] = gl_buf[i];
@@ -608,7 +608,7 @@ gl_yank()
     if (len > 0) {
 	if (gl_overwrite == 0) {
             if (gl_cnt + len >= BUF_SIZE - 1) 
-	        gl_error("\n*** Error: getline(): input buffer overflow\n");
+	        gl_error("\n*** Error: get_line(): input buffer overflow\n");
             for (i=gl_cnt; i >= gl_pos; i--)
                 gl_buf[i+len] = gl_buf[i];
 	    for (i=0; i < len; i++)
@@ -617,7 +617,7 @@ gl_yank()
 	} else {
 	    if (gl_pos + len > gl_cnt) {
                 if (gl_pos + len >= BUF_SIZE - 1) 
-	            gl_error("\n*** Error: getline(): input buffer overflow\n");
+	            gl_error("\n*** Error: get_line(): input buffer overflow\n");
 		gl_buf[gl_pos + len] = 0;
             }
 	    for (i=0; i < len; i++)
@@ -657,7 +657,7 @@ gl_newline()
     int loc = gl_width - 5;	/* shifts line back to start position */
 
     if (gl_cnt >= BUF_SIZE - 1) 
-        gl_error("\n*** Error: getline(): input buffer overflow\n");
+        gl_error("\n*** Error: get_line(): input buffer overflow\n");
     if (gl_out_hook) {
 	change = gl_out_hook(gl_buf);
         len = strlen(gl_buf);
@@ -916,7 +916,7 @@ char *buf;
     char *p = buf;
     int len;
 
     /* in case we call gl_histadd() before we call getline() */
     if (gl_init_done < 0) {		/* -1 only on startup */
         hist_init();
         gl_init_done = 0;
@@ -916,7 +916,7 @@ char *buf;
     int len;
 
-    /* in case we call gl_histadd() before we call getline() */
+    /* in case we call gl_histadd() before we call get_line() */
     if (gl_init_done < 0) {		/* -1 only on startup */
         hist_init();